if(!self.define){let e,i={};const n=(n,s)=>(n=new URL(n+".js",s).href,i[n]||new Promise(i=>{if("document"in self){const e=document.createElement("script");e.src=n,e.onload=i,document.head.appendChild(e)}else e=n,importScripts(n),i()}).then(()=>{let e=i[n];if(!e)throw new Error(`Module ${n} didn’t register its module`);return e}));self.define=(s,c)=>{const o=e||("document"in self?document.currentScript.src:"")||location.href;if(i[o])return;let r={};const f=e=>n(e,o),t={module:{uri:o},exports:r,require:f};i[o]=Promise.all(s.map(e=>t[e]||f(e))).then(e=>(c(...e),r))}}define(["./workbox-8c29f6e4"],function(e){"use strict";self.skipWaiting(),e.clientsClaim(),e.precacheAndRoute([{url:"registerSW.js",revision:"1872c500de691dce40960bb85481de07"},{url:"index.html",revision:"dac48324fb750fc07ddfb71861a5e422"},{url:"favicon.png",revision:"238a0f62abe3c224aaf4486454331f4c"},{url:"icons/icon-512.png",revision:"83483981a918c4d7c95fa01cb650d1f7"},{url:"icons/icon-192.png",revision:"a834952b7e5cb111b774554f3f2c667a"},{url:"icons/icon-180.png",revision:"4c8170590f4fa65b3255c4196d4e4357"},{url:"assets/index-x8zRssZP.css",revision:null},{url:"assets/index-DY0vi7cv.js",revision:null},{url:"icons/icon-192.png",revision:"a834952b7e5cb111b774554f3f2c667a"},{url:"icons/icon-512.png",revision:"83483981a918c4d7c95fa01cb650d1f7"},{url:"manifest.webmanifest",revision:"29003628192644e0fc3e6e57f2f999f7"}],{}),e.cleanupOutdatedCaches(),e.registerRoute(new e.NavigationRoute(e.createHandlerBoundToURL("/index.html"),{denylist:[/^\/api/,/^\/ws/]}))});
